@@ -1,8 +1,12 @@
 from django.apps import apps
 from django.conf import settings
+from django.contrib.auth import _get_user_session_key
 from django.contrib.auth import get_user
 from django.contrib.auth.middleware import AuthenticationMiddleware
+from django.contrib.sessions.middleware import SessionMiddleware
+from django.core.cache import cache
 from django.core.exceptions import ImproperlyConfigured
+from django.db.models.signals import post_save
 from django.utils.functional import SimpleLazyObject
 
 
@@ -38,10 +42,20 @@ def get_anonymous_user_model():
         )
 
 
-def _get_user(request):
+USER_SESSION_CACHE_KEY = "USER_BY_SESSION_CACHE_{}"
 
+
+def _get_user(request):
     if not hasattr(request, "_cached_user"):
-        user = get_user(request)
+        try:
+            user_id = _get_user_session_key(request)
+            USER_CACHE_KEY = USER_SESSION_CACHE_KEY.format(user_id)
+            user = cache.get(USER_CACHE_KEY)
+            if not user:
+                user = get_user(request)
+                cache.set(USER_CACHE_KEY, user)
+        except KeyError:
+            user = get_user(request)
         if user.is_anonymous():
             AnonymousUser = get_anonymous_user_model()
             user = AnonymousUser()
@@ -50,6 +64,14 @@ def _get_user(request):
     return request._cached_user
 
 
+def clear_user_cache(sender, instance, created, **kwargs):
+    if not created:
+        cache.delete(USER_SESSION_CACHE_KEY.format(instance.id))
+
+
+post_save.connect(clear_user_cache, sender=settings.AUTH_USER_MODEL)
+
+
 class CustomAuthenticationMiddleware(AuthenticationMiddleware):
     """
     Adaptation of Django's ``account.middleware.AuthenticationMiddleware``
@@ -57,12 +79,13 @@ class CustomAuthenticationMiddleware(AuthenticationMiddleware):
     """
 
     def process_request(self, request):
-        assert hasattr(request, "session"), (
-            "The authentication middleware requires session middleware "
-            "to be installed. Edit your MIDDLEWARE_CLASSES setting to insert "
-            "'django.contrib.sessions.middleware.SessionMiddleware' before "
-            "'kolibri.core.auth.middleware.CustomAuthenticationMiddleware'."
-        )
+        if not hasattr(request, "session"):
+            raise AssertionError(
+                "The authentication middleware requires session middleware "
+                "to be installed. Edit your MIDDLEWARE_CLASSES setting to insert "
+                "'django.contrib.sessions.middleware.SessionMiddleware' before "
+                "'kolibri.core.auth.middleware.CustomAuthenticationMiddleware'."
+            )
         request.user = SimpleLazyObject(lambda: _get_user(request))
 
 
@@ -86,3 +109,29 @@ class XhrPreventLoginPromptMiddleware(object):
         if response and response.status_code == 401 and request.is_ajax():
             del response["WWW-Authenticate"]
         return response
+
+
+SESSION_EXEMPT = "_session_exempt"
+
+
+def session_exempt(view):
+    def wrapper_func(*args, **kwargs):
+        return view(*args, **kwargs)
+
+    setattr(wrapper_func, SESSION_EXEMPT, True)
+    return wrapper_func
+
+
+class KolibriSessionMiddleware(SessionMiddleware):
+    def _is_exempt(self, obj):
+        return hasattr(obj, SESSION_EXEMPT)
+
+    def process_view(self, request, callback, callback_args, callback_kwargs):
+        if self._is_exempt(callback):
+            setattr(request, SESSION_EXEMPT, True)
+        return None
+
+    def process_response(self, request, response):
+        if self._is_exempt(request):
+            return response
+        return super(KolibriSessionMiddleware, self).process_response(request, response)
