@@ -3,8 +3,10 @@ import json
 import os
 
 # load stopwords file
-stopwords_path = os.path.join(
-    os.path.dirname(__file__), os.path.pardir, "constants", "stopwords-all.json"
+stopwords_path = os.path.abspath(
+    os.path.join(
+        os.path.dirname(__file__), os.path.pardir, "constants", "stopwords-all.json"
+    )
 )
 with io.open(stopwords_path, mode="r", encoding="utf-8") as f:
     stopwords = json.load(f)
