@@ -11,7 +11,6 @@ import tempfile
 import pytest
 from mock import patch
 
-import kolibri
 from kolibri.plugins.utils import autoremove_unavailable_plugins
 from kolibri.utils import cli
 from kolibri.utils import options
@@ -156,7 +155,7 @@ def test_kolibri_listen_port_env(monkeypatch):
         def start_mock(port, *args, **kwargs):
             assert port == test_port
             try:
-                os.remove(server.STARTUP_LOCK)
+                os.remove(server.PID_FILE)
             except OSError:
                 pass
 
@@ -165,14 +164,16 @@ def test_kolibri_listen_port_env(monkeypatch):
 
         test_port = 1234
 
+        test_zip_port = 5432
+
         os.environ["KOLIBRI_HTTP_PORT"] = str(test_port)
 
         # force a reload of plugins.OPTIONS so the environment variable will be read in
         from kolibri.utils import conf
 
-        conf.OPTIONS.update(options.read_options_file(conf.KOLIBRI_HOME))
+        conf.OPTIONS.update(options.read_options_file())
 
-        cli.start.callback(test_port, False)
+        cli.start.callback(test_port, test_zip_port, False)
         with pytest.raises(SystemExit) as excinfo:
             cli.stop.callback()
             assert excinfo.code == 0
@@ -188,85 +189,13 @@ def test_kolibri_listen_port_env(monkeypatch):
         def status_starting_up():
             raise server.NotRunning(server.STATUS_STARTING_UP)
 
-        # Ensure that if a server is reported to be 'starting up', it doesn't
-        # get killed while doing that.
+        # Ensure that if a server is reported to be 'starting up', it still
+        # successfully shuts down.
         monkeypatch.setattr(server, "get_status", status_starting_up)
         with pytest.raises(SystemExit) as excinfo:
             cli.stop.callback()
             assert excinfo.code == server.STATUS_STARTING_UP
-        assert "Not stopped" in LOG_LOGGER[-1][1]
-
-
-@pytest.mark.django_db
-@patch("kolibri.utils.cli.get_version", return_value="")
-@patch("kolibri.utils.cli.update")
-@patch("kolibri.utils.cli.plugin.callback")
-@patch("kolibri.core.deviceadmin.utils.dbbackup")
-def test_first_run(dbbackup, plugin, update, get_version):
-    """
-    Tests that the first_run() function performs as expected
-    """
-
-    cli.initialize()
-    update.assert_called_once()
-    dbbackup.assert_not_called()
-
-    # Check that it got called for each default plugin
-    from kolibri import plugins
-
-    assert set(plugins.config["INSTALLED_PLUGINS"]) == set(plugins.DEFAULT_PLUGINS)
-
-
-@pytest.mark.django_db
-@patch("kolibri.utils.cli.get_version", return_value="0.0.1")
-@patch("kolibri.utils.cli.update")
-def test_update(update, get_version):
-    """
-    Tests that update() function performs as expected
-    """
-    cli.initialize()
-    update.assert_called_once()
-
-
-@pytest.mark.django_db
-@patch("kolibri.utils.cli.get_version", return_value="0.0.1")
-def test_update_exits_if_running(get_version):
-    """
-    Tests that update() function performs as expected
-    """
-    with patch("kolibri.utils.cli.server.get_status"):
-        try:
-            cli.initialize()
-            pytest.fail("Update did not exit when Kolibri was already running")
-        except SystemExit:
-            pass
-
-
-@pytest.mark.django_db
-def test_version_updated():
-    """
-    Tests our db backup logic: version_updated gets any change, backup gets only non-dev changes
-    """
-    assert cli.version_updated("0.10.0", "0.10.1")
-    assert not cli.version_updated("0.10.0", "0.10.0")
-    assert not cli.should_back_up("0.10.0-dev0", "")
-    assert not cli.should_back_up("0.10.0-dev0", "0.10.0")
-    assert not cli.should_back_up("0.10.0", "0.10.0-dev0")
-    assert not cli.should_back_up("0.10.0-dev0", "0.10.0-dev0")
-
-
-@pytest.mark.django_db
-@patch("kolibri.utils.cli.get_version", return_value=kolibri.__version__)
-@patch("kolibri.utils.cli.update")
-@patch("kolibri.core.deviceadmin.utils.dbbackup")
-def test_update_no_version_change(dbbackup, update, get_version):
-    """
-    Tests that when the version doesn't change, we are not doing things we
-    shouldn't
-    """
-    cli.initialize()
-    update.assert_not_called()
-    dbbackup.assert_not_called()
+        assert "successfully been stopped" in LOG_LOGGER[-1][1]
 
 
 def test_cli_usage():
